const GIRepository = imports.gi.GIRepository;
const GLib = imports.gi.GLib;
let libdir = GIRepository.Repository.get_search_path().find(path => {
  return path.endsWith("/gjs/girepository-1.0");
}).replace("/gjs/girepository-1.0", "");
const gsdir = GLib.build_filenamev([libdir, "gnome-shell"]);
if (!GLib.file_test(gsdir, GLib.FileTest.IS_DIR)) {
  const currentDir = `/${GLib.path_get_basename(libdir)}`;
  libdir = libdir.replace(currentDir, "");
}
const typelibDir = GLib.build_filenamev([libdir, "gnome-shell"]);
GIRepository.Repository.prepend_search_path(typelibDir);
GIRepository.Repository.prepend_library_path(typelibDir);
var prefs = (function (adw1, gtk4) {
    'use strict';

    const ExtensionUtils = imports.misc.extensionUtils;
    const SettingsPath = "org.gnome.shell.extensions.quicksettings-audio-devices-hider";
    const ExcludedOutputNamesSetting = "excluded-output-names";
    const AvailableOutputNames = "available-output-names";
    class SettingsUtils {
        static getExcludedOutputDeviceNames() {
            const settings = ExtensionUtils.getSettings(SettingsPath);
            const ids = settings.get_strv(ExcludedOutputNamesSetting);
            return ids;
        }
        static setExcludedOutputDeviceNames(displayNames) {
            const settings = ExtensionUtils.getSettings(SettingsPath);
            settings.set_strv(ExcludedOutputNamesSetting, displayNames);
        }
        static addToExcludedOutputDeviceNames(displayName) {
            const currentOutputs = SettingsUtils.getExcludedOutputDeviceNames();
            if (currentOutputs.includes(displayName)) {
                return;
            }
            const newOutputs = [...currentOutputs, displayName];
            const settings = ExtensionUtils.getSettings(SettingsPath);
            log("Setting " + newOutputs);
            settings.set_strv(ExcludedOutputNamesSetting, newOutputs);
        }
        static removeFromExcludedOutputDeviceNames(displayName) {
            const outputs = SettingsUtils.getExcludedOutputDeviceNames();
            const index = outputs.indexOf(displayName);
            if (index === -1) {
                return;
            }
            outputs.splice(index, 1);
            const settings = ExtensionUtils.getSettings(SettingsPath);
            settings.set_strv(ExcludedOutputNamesSetting, outputs);
        }
        static getAvailableOutputs() {
            const settings = ExtensionUtils.getSettings(SettingsPath);
            const ids = settings.get_strv(AvailableOutputNames);
            return ids;
        }
        static setAvailableOutputs(displayNames) {
            const settings = ExtensionUtils.getSettings(SettingsPath);
            settings.set_strv(AvailableOutputNames, displayNames.map((id) => id.toString()));
        }
        static addToAvailableOutputs(displayName) {
            const currentOutputs = SettingsUtils.getAvailableOutputs();
            if (currentOutputs.includes(displayName)) {
                return;
            }
            const newAllOutputs = [...currentOutputs, displayName];
            const settings = ExtensionUtils.getSettings(SettingsPath);
            settings.set_strv(AvailableOutputNames, newAllOutputs.map((id) => id.toString()));
        }
        static removeFromAvailableOutputs(displayName) {
            const outputs = SettingsUtils.getAvailableOutputs();
            const index = outputs.indexOf(displayName);
            if (index === -1) {
                return;
            }
            outputs.splice(index, 1);
            const settings = ExtensionUtils.getSettings(SettingsPath);
            settings.set_strv(AvailableOutputNames, outputs.map((id) => id.toString()));
        }
    }

    function init() { }
    function fillPreferencesWindow(window) {
        const page = new adw1.PreferencesPage();
        window.add(page);
        const allDevices = SettingsUtils.getAvailableOutputs();
        const hiddenDevices = SettingsUtils.getExcludedOutputDeviceNames();
        var visibleDevices = allDevices.filter((device) => !hiddenDevices.includes(device));
        const group = new adw1.PreferencesGroup({
            title: "Output Audio Devices",
            description: "Choose which devices should be visible in the Quick Setting panel",
        });
        page.add(group);
        visibleDevices.forEach((device) => {
            group.add(createDeviceRow(device, true));
        });
        hiddenDevices.forEach((device) => {
            group.add(createDeviceRow(device, false));
        });
    }
    function createDeviceRow(displayName, active) {
        const row = new adw1.ActionRow({ title: displayName });
        const toggle = new gtk4.Switch({
            active,
            valign: gtk4.Align.CENTER,
        });
        toggle.connect("state-set", (_, state) => {
            if (state) {
                SettingsUtils.removeFromExcludedOutputDeviceNames(displayName);
            }
            else {
                SettingsUtils.addToExcludedOutputDeviceNames(displayName);
            }
            return false;
        });
        row.add_suffix(toggle);
        row.activatable_widget = toggle;
        return row;
    }
    var prefs = { init, fillPreferencesWindow };

    return prefs;

})(imports.gi.Adw, imports.gi.Gtk);
var init = prefs.init;
var fillPreferencesWindow = prefs.fillPreferencesWindow;
